function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var react = require('react');
var reactRedux = require('react-redux');
var _ = _interopDefault(require('lodash'));

function useReduxEffect(effect, type, deps) {
  if (deps === void 0) {
    deps = [];
  }

  var currentValue = react.useRef(null);
  var store = reactRedux.useStore();

  var handleChange = function handleChange() {
    var state = store.getState();
    var action = state.action;
    var previousValue = currentValue.current;
    currentValue.current = action.count;

    if (previousValue !== action.count && _.castArray(type).includes(action.type)) {
      effect(action);
    }
  };

  react.useEffect(function () {
    var unsubscribe = store.subscribe(handleChange);
    return function () {
      return unsubscribe();
    };
  }, deps);
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var initialState = {
  type: null,
  payload: null,
  meta: null,
  error: false,
  count: 0
};
var actionReducer = function actionReducer(state, action) {
  if (state === void 0) {
    state = initialState;
  }

  return _extends({}, state, action, {
    count: state.count + 1
  });
};

exports.actionReducer = actionReducer;
exports.useReduxEffect = useReduxEffect;
//# sourceMappingURL=index.js.map
